pub struct BlockHeader {
pub timestamp: Option<Timestamp>,
pub producer: String,
pub confirmed: u32,
pub previous: String,
pub transaction_mroot: Vec<u8>,
pub action_mroot: Vec<u8>,
pub schedule_version: u32,
pub header_extensions: Vec<Extension>,
pub decoded_header_extensions: Vec<BlockHeaderExtension>,
pub new_producers_v1: Option<ProducerSchedule>,
}Fields
timestamp: Option<Timestamp>producer: Stringconfirmed: u32uint16
previous: Stringtransaction_mroot: Vec<u8>action_mroot: Vec<u8>schedule_version: u32header_extensions: Vec<Extension>decoded_header_extensions: Vec<BlockHeaderExtension>new_producers_v1: Option<ProducerSchedule>EOSIO 1.x only
A change to producer schedule was reported as a NewProducers field on the
BlockHeader in EOSIO 1.x. In EOSIO 2.x, when feature WTMSIG_BLOCK_SIGNATURES
is activated, the NewProducers field is not present anymore and the schedule change
is reported through a BlockHeaderExtension on the the BlockHeader struct.
If you need to access the old value, you can